@@ -2,6 +2,8 @@ import datetime
 import time
 import hashlib
 import os
+import re
+import getpass
 import tempfile
 import requests
 import json
@@ -241,4 +243,66 @@ def initConf(configFile):
     else:
         raise ValueError(f"{configFile}: not File")
 
+def modifyFileBelong(filePath, user=None, group=None):
+    import pwd
+    import grp
+
+    if not user:
+        user = getpass.getuser()
+    if not group:
+        group = user
+
+    uid = pwd.getpwnam(user).pw_uid
+    gid = grp.getgrnam(group).gr_gid
+    os.chown(filePath, uid, gid)
+
+
+def cleanDate(data, reg, repl=''):
+    return re.sub(reg, repl or '', data).strip()
+
+def getUrlArgs(url, cleanReg=None, repl=''):
+    if cleanReg:
+        url = cleanDate(url, cleanReg, repl=repl)
+    urlParsed = urlparse(url)
+    query = urlParsed.query
+    tmpList = query.split('&')
+    ks = [line.split('=', maxsplit=1)[0] for line in tmpList]
+    vals = [line.split('=', maxsplit=1)[-1] for line in tmpList]
+    args = dict(zip(ks, vals))
+    api = f"{urlParsed.scheme}://{urlParsed.netloc}{urlParsed.path}"
+    return api, args
+
+def timestampToDatetime(timestamp):
+    return datetime.datetime.strptime(time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(int(timestamp))), "%Y-%m-%d %H:%M:%S")
+
+def isdigit(v):
+    v = str(v)
+    b = False
+    if v.isdigit():
+        b = True
+    else:
+        try:
+            float(v)
+            b = True
+        except:
+            pass
+    return b
+
+
+def transformReqToJson(request):
+    try:
+        res = request.json
+    except:
+        res = dict(request.form) or dict(request.args)
+    return res
+
+def getExceptionJson(exception):
+    dic = {}
+    fields = ['message','status_code', 'quiet', 'context', 'extra']
+    args = exception.args
+    for i in range(len(args)):
+        v = args[i]
+        dic.setdefault(fields[i], v)
+    return dic
+
 
