@@ -213,7 +213,8 @@ class PgDb:
         with conn.cursor() as cur:
             try:
                 ret = cur.execute(query, kwparameters or parameters)
-                ret = ret.statusmessage
+                # ret = ret.statusmessage
+                ret = ret and hasattr(ret, 'statusmessage') and ret.statusmessage or None
                 conn.commit()
             except Exception as e:
                 print(f"{self.name}:  -- {traceback.format_exc()}")
@@ -232,7 +233,7 @@ class PgDb:
         with conn.cursor() as cur:
             try:
                 ret = cur.executemany(query, kwparameters or parameters)
-                ret = ret.statusmessage
+                ret = ret and hasattr(ret, 'statusmessage') and ret.statusmessage or None
                 conn.commit()
             except Exception as e:
                 print(f"{self.name}:  -- {traceback.format_exc()}")
@@ -396,18 +397,3 @@ class PgDb:
 
         print(f"{self.name}: {ret}")
         return ret
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
