@@ -10,7 +10,7 @@ class RetrieveUA:
 
     @classmethod
     def getRandomUa(cls, **kwargs):
-        if not hasattr(cls, 'ua'):
+        if not cls.ua:
             cls.init(**kwargs)
         return cls.ua.random
 
