@@ -13,10 +13,11 @@ async def get(url):
         url,
         isSplash=True
     )
-    print(res)
+    print(res['content'].decode())
 
 if __name__ == '__main__':
-    asyncio.run(get("http://httpbin.org/get"))
+    # asyncio.run(get("http://httpbin.org/get"))
+    asyncio.run(get("https://haokan.baidu.com/tab/shenghuo_new"))
 
 
 
